@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: mem.h,v 1.14 1999/02/23 11:42:56 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -46,15 +44,15 @@ typedef struct _glibtop_mem	glibtop_mem;
 
 struct _glibtop_mem
 {
-    u_int64_t	flags,
-	total,		/* GLIBTOP_MEM_TOTAL	*/
-	used,		/* GLIBTOP_MEM_USED	*/
-	free,		/* GLIBTOP_MEM_FREE	*/
-	shared,		/* GLIBTOP_MEM_SHARED	*/
-	buffer,		/* GLIBTOP_MEM_BUFFER	*/
-	cached,		/* GLIBTOP_MEM_CACHED	*/
-	user,		/* GLIBTOP_MEM_USER	*/
-	locked;		/* GLIBTOP_MEM_LOCKED	*/
+	u_int64_t	flags,
+		total,		/* GLIBTOP_MEM_TOTAL	*/
+		used,		/* GLIBTOP_MEM_USED	*/
+		free,		/* GLIBTOP_MEM_FREE	*/
+		shared,		/* GLIBTOP_MEM_SHARED	*/
+		buffer,		/* GLIBTOP_MEM_BUFFER	*/
+		cached,		/* GLIBTOP_MEM_CACHED	*/
+		user,		/* GLIBTOP_MEM_USER	*/
+		locked;		/* GLIBTOP_MEM_LOCKED	*/
 };
 
 #define glibtop_get_mem(mem)	glibtop_get_mem_l(glibtop_global_server, mem)
@@ -65,14 +63,14 @@ struct _glibtop_mem
 #define glibtop_get_mem_r		glibtop_get_mem_s
 #endif
 
-int glibtop_get_mem_l (glibtop *server, glibtop_mem *buf);
+void glibtop_get_mem_l (glibtop *server, glibtop_mem *buf);
 
 #if GLIBTOP_SUID_MEM
-int glibtop_init_mem_p (glibtop *server);
-int glibtop_get_mem_p (glibtop *server, glibtop_mem *buf);
+void glibtop_init_mem_p (glibtop *server);
+void glibtop_get_mem_p (glibtop *server, glibtop_mem *buf);
 #else
-int glibtop_init_mem_s (glibtop *server);
-int glibtop_get_mem_s (glibtop *server, glibtop_mem *buf);
+void glibtop_init_mem_s (glibtop *server);
+void glibtop_get_mem_s (glibtop *server, glibtop_mem *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
