@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procsegment.h,v 1.14 1999/02/23 11:43:09 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,18 +36,9 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_PROC_SEGMENT_DIRTY_SIZE		4
 #define GLIBTOP_PROC_SEGMENT_START_CODE		5
 #define GLIBTOP_PROC_SEGMENT_END_CODE		6
-#define GLIBTOP_PROC_SEGMENT_START_DATA		7
-#define GLIBTOP_PROC_SEGMENT_END_DATA		8
-#define GLIBTOP_PROC_SEGMENT_START_BRK		9
-#define GLIBTOP_PROC_SEGMENT_END_BRK		10
-#define GLIBTOP_PROC_SEGMENT_START_STACK	11
-#define GLIBTOP_PROC_SEGMENT_START_MMAP		12
-#define GLIBTOP_PROC_SEGMENT_ARG_START		13
-#define GLIBTOP_PROC_SEGMENT_ARG_END		14
-#define GLIBTOP_PROC_SEGMENT_ENV_START		15
-#define GLIBTOP_PROC_SEGMENT_ENV_END		16
+#define GLIBTOP_PROC_SEGMENT_START_STACK	7
 
-#define GLIBTOP_MAX_PROC_SEGMENT		17
+#define GLIBTOP_MAX_PROC_SEGMENT		8
 
 typedef struct _glibtop_proc_segment	glibtop_proc_segment;
 
@@ -57,24 +46,16 @@ typedef struct _glibtop_proc_segment	glibtop_proc_segment;
 
 struct _glibtop_proc_segment
 {
-    u_int64_t	flags,
-	text_rss,	/* text resident set size */
-	shlib_rss,	/* shared-lib resident set size */
-	data_rss,	/* data resident set size */
-	stack_rss,	/* stack resident set size */
-	dirty_size,	/* size of dirty pages */
-	start_code,	/* address of beginning of code segment */
-	end_code,	/* address of end of code segment */
-	start_data,	/* address of beginning of data segment */
-	end_data,	/* address of end of data segment */
-	start_brk,
-	end_brk,
-	start_stack,	/* address of the bottom of stack segment */
-	start_mmap,
-	arg_start,
-	arg_end,
-	env_start,
-	env_end;
+	u_int64_t	flags,
+		text_rss,	/* text resident set size */
+		shlib_rss,	/* shared-lib resident set size */
+		data_rss,	/* data resident set size */
+		stack_rss,	/* stack resident set size */
+		dirty_size,	/* size of dirty pages */
+		start_code,
+				/* address of beginning of code segment */
+		end_code,	/* address of end of code segment */
+		start_stack;	/* address of the bottom of stack segment */
 };
 
 #define glibtop_get_proc_segment(p1, p2)	glibtop_get_proc_segment_l(glibtop_global_server, p1, p2)
@@ -85,14 +66,14 @@ struct _glibtop_proc_segment
 #define glibtop_get_proc_segment_r	glibtop_get_proc_segment_s
 #endif
 
-int glibtop_get_proc_segment_l (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
+void glibtop_get_proc_segment_l (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_SEGMENT
-int glibtop_init_proc_segment_p (glibtop *server);
-int glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
+void glibtop_init_proc_segment_p (glibtop *server);
+void glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
 #else
-int glibtop_init_proc_segment_s (glibtop *server);
-int glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
+void glibtop_init_proc_segment_s (glibtop *server);
+void glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
