@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id: types.h,v 1.6 1999/03/31 16:52:54 martin Exp $ */
+/* $Id: types.h,v 1.4 1999/02/23 11:43:22 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,9 +30,8 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_TYPE_ULONG	2
 #define GLIBTOP_TYPE_DOUBLE	3
 #define GLIBTOP_TYPE_INT	4
-#define GLIBTOP_TYPE_UNSIGNED	5
-#define GLIBTOP_TYPE_CHAR	6
-#define GLIBTOP_TYPE_STRING	7
+#define GLIBTOP_TYPE_CHAR	5
+#define GLIBTOP_TYPE_STRING	6
 
 END_LIBGTOP_DECLS
 
