@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: loadavg.c,v 1.6.2.1 1999/05/27 14:03:56 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -34,33 +32,29 @@ static const unsigned long _glibtop_sysdeps_loadavg =
 
 /* Init function. */
 
-int
+void
 glibtop_init_loadavg_p (glibtop *server)
 {
-    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
-
-    return 0;
+	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
 /* Provides load averange. */
 
-int
+void
 glibtop_get_loadavg_p (glibtop *server, glibtop_loadavg *buf)
 {
-    double ldavg[3]; 
-    int i;
+	double ldavg[3]; 
+	int i;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_LOADAVG), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_LOADAVG), 0);
 	
-    memset (buf, 0, sizeof (glibtop_loadavg));
+	memset (buf, 0, sizeof (glibtop_loadavg));
 
-    getloadavg (ldavg, 3);
+	getloadavg (ldavg, 3);
   
-    /* fill in the struct */
-    buf->flags = _glibtop_sysdeps_loadavg;
-    for (i = 0; i < 3; i++) {
-	buf->loadavg [i] = ldavg [i];
-    } /* end for */
-
-    return 0;
+	/* fill in the struct */
+	buf->flags = _glibtop_sysdeps_loadavg;
+	for (i = 0; i < 3; i++) {
+		buf->loadavg [i] = ldavg [i];
+	} /* end for */
 }
