@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: msg_limits.c,v 1.8.2.1 1999/05/27 19:24:15 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,43 +27,39 @@
 #include <sys/msg.h>
 
 static const unsigned long _glibtop_sysdeps_msg_limits =
-(1L << GLIBTOP_MSG_LIMITS_MSGPOOL) + (1L << GLIBTOP_MSG_LIMITS_MSGMAP) +
-(1L << GLIBTOP_MSG_LIMITS_MSGMAX) + (1L << GLIBTOP_MSG_LIMITS_MSGMNB) +
-(1L << GLIBTOP_MSG_LIMITS_MSGMNI) + (1L << GLIBTOP_MSG_LIMITS_MSGSSZ) +
-(1L << GLIBTOP_MSG_LIMITS_MSGTQL);
+(1L << GLIBTOP_IPC_MSGPOOL) + (1L << GLIBTOP_IPC_MSGMAP) +
+(1L << GLIBTOP_IPC_MSGMAX) + (1L << GLIBTOP_IPC_MSGMNB) +
+(1L << GLIBTOP_IPC_MSGMNI) + (1L << GLIBTOP_IPC_MSGSSZ) +
+(1L << GLIBTOP_IPC_MSGTQL);
 
 /* Init function. */
 
-int
+void
 glibtop_init_msg_limits_s (glibtop *server)
 {
-    server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
-
-    return 0;
+	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 {
-    struct msginfo	msginfo;
+	struct msginfo	msginfo;
   
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_MSG_LIMITS, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MSG_LIMITS, 0);
 
-    memset (buf, 0, sizeof (glibtop_msg_limits));
+	memset (buf, 0, sizeof (glibtop_msg_limits));
   
-    buf->flags = _glibtop_sysdeps_msg_limits;
+	buf->flags = _glibtop_sysdeps_msg_limits;
   
-    msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo);
+	msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo);
   
-    buf->msgpool = msginfo.msgpool;
-    buf->msgmap = msginfo.msgmap;
-    buf->msgmax = msginfo.msgmax;
-    buf->msgmnb = msginfo.msgmnb;
-    buf->msgmni = msginfo.msgmni;
-    buf->msgssz = msginfo.msgssz;
-    buf->msgtql = msginfo.msgtql;
-
-    return 0;
+	buf->msgpool = msginfo.msgpool;
+	buf->msgmap = msginfo.msgmap;
+	buf->msgmax = msginfo.msgmax;
+	buf->msgmnb = msginfo.msgmnb;
+	buf->msgmni = msginfo.msgmni;
+	buf->msgssz = msginfo.msgssz;
+	buf->msgtql = msginfo.msgtql;
 }
