@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procmap.c,v 1.2 1999/02/23 11:46:57 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,12 +30,10 @@ static const unsigned long _glibtop_sysdeps_proc_map = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_map_p (glibtop *server)
 {
-    server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
-
-    return 0;
+	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
 }
 
 /* Provides detailed information about a process. */
@@ -45,6 +41,6 @@ glibtop_init_proc_map_p (glibtop *server)
 glibtop_map_entry *
 glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 {
-    memset (buf, 0, sizeof (glibtop_proc_map));
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proc_map));
+	return NULL;
 }
