@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procuid.c,v 1.3 1999/02/23 11:47:03 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,23 +31,19 @@ static const unsigned long _glibtop_sysdeps_proc_uid = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_uid_p (glibtop *server)
 {
-    server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
-
-    return 0;
+	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 			pid_t pid)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_UID, 0);
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_UID, 0);
 	
-    memset (buf, 0, sizeof (glibtop_proc_uid));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_uid));
 }
