@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procsignal.c,v 1.9 1999/02/23 11:47:27 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,37 +27,37 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_signal =
-(1L << GLIBTOP_PROC_SIGNAL_SIGNAL) + (1L << GLIBTOP_PROC_SIGNAL_BLOCKED) +
-(1L << GLIBTOP_PROC_SIGNAL_SIGIGNORE) + (1L << GLIBTOP_PROC_SIGNAL_SIGCATCH);
+(1 << GLIBTOP_PROC_SIGNAL_SIGNAL) + (1 << GLIBTOP_PROC_SIGNAL_BLOCKED) +
+(1 << GLIBTOP_PROC_SIGNAL_SIGIGNORE) + (1 << GLIBTOP_PROC_SIGNAL_SIGCATCH);
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_signal_p (glibtop *server, glibtop_proc_signal *buf,
 			   pid_t pid)
 {
-    struct proc *pp;
+	struct proc *pp;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
 
-    memset (buf, 0, sizeof (glibtop_proc_signal));
+	memset (buf, 0, sizeof (glibtop_proc_signal));
 
-    /* Read process table from kernel. */	
+	/* Read process table from kernel. */	
 
-    _glibtop_read_proc_table (server);
+	_glibtop_read_proc_table (server);
 
-    /* Find the pid in the process table. */
+	/* Find the pid in the process table. */
 
-    pp = _glibtop_find_pid (server, pid);
+	pp = _glibtop_find_pid (server, pid);
 
-    if (pp == NULL)	return;
+	if (pp == NULL)	return;
 
-    /* Fill in data fields. */
+	/* Fill in data fields. */
 
-    buf->signal [0] = pp->p_sig;
-    buf->blocked [0] = pp->p_sigmask;
-    buf->sigignore [0] = pp->p_sigignore;
-    buf->sigcatch [0] = pp->p_sigcatch;
+	buf->signal [0] = pp->p_sig;
+	buf->blocked [0] = pp->p_sigmask;
+	buf->sigignore [0] = pp->p_sigignore;
+	buf->sigcatch [0] = pp->p_sigcatch;
 	
-    buf->flags = _glibtop_sysdeps_proc_signal;
+	buf->flags = _glibtop_sysdeps_proc_signal;
 }
